diff pidgin/plugins/crazychat/cc_network.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children
line wrap: on
line diff
--- a/pidgin/plugins/crazychat/cc_network.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/pidgin/plugins/crazychat/cc_network.h	Mon Mar 19 07:01:17 2007 +0000
@@ -34,20 +34,20 @@
  * Creates a new CrazyChat session if one doesn't exist and sends the invite.
  * @param cc		global crazychat data structure
  * @param name		the peer name
  * @param account	the gaim account
  */
-void cc_net_send_invite(struct crazychat *cc, char *name, GaimAccount *account);
+void cc_net_send_invite(struct crazychat *cc, char *name, PurpleAccount *account);
 
 /**
  * Pops up the CrazyChat invitation accept window if a CrazyChat session does
  * not exist yet for this peer.
  * @param account	gaim account
  * @param cc		global crazychat data structure
  * @param name		the peer name
  * @param peer_ip	the peer's ip address
  * @param peer_port	the peer's tcp port
  */
-void cc_net_recv_invite(GaimAccount *account, struct crazychat *cc, char *name,
+void cc_net_recv_invite(PurpleAccount *account, struct crazychat *cc, char *name,
 		const char *peer_ip, const char *peer_port);
 
 /**
@@ -59,20 +59,20 @@
 /**
  * Receives a CrazyChat accept message, and if appropriate, creates a server
  * socket and sends the ready message.
  * @param account	the gaim account which received the message
  * @param cc		global crazychat data structure
  * @param name		the peer name
  * @param peer_ip	the peer's ip address
  */
-void cc_net_recv_accept(GaimAccount *account, struct crazychat *cc, char *name,
+void cc_net_recv_accept(PurpleAccount *account, struct crazychat *cc, char *name,
 		const char *peer_ip);
 
 /**
  * Receives a CrazyChat ready message, and if appropriate, connects to peer
  * @param account	the gaim account which received the message
  * @param cc		global crazychat data structure
  * @param name		the peer name
  */
-void cc_net_recv_ready(GaimAccount *account, struct crazychat *cc, char *name);
+void cc_net_recv_ready(PurpleAccount *account, struct crazychat *cc, char *name);
 
 #endif
@@ -34,20 +34,20 @@
  * @param cc		global crazychat data structure
  * @param name		the peer name
- * @param account	the gaim account
+ * @param account	the purple account
  */
@@ -34,20 +34,20 @@
  * Pops up the CrazyChat invitation accept window if a CrazyChat session does
  * not exist yet for this peer.
- * @param account	gaim account
+ * @param account	purple account
  * @param cc		global crazychat data structure
  * @param name		the peer name
@@ -59,20 +59,20 @@
  * Receives a CrazyChat accept message, and if appropriate, creates a server
  * socket and sends the ready message.
- * @param account	the gaim account which received the message
+ * @param account	the purple account which received the message
  * @param cc		global crazychat data structure
  * @param name		the peer name
@@ -59,20 +59,20 @@
 /**
  * Receives a CrazyChat ready message, and if appropriate, connects to peer
- * @param account	the gaim account which received the message
+ * @param account	the purple account which received the message
  * @param cc		global crazychat data structure
  * @param name		the peer name